@@ -18,8 +18,8 @@ def add_str(s0, s1):
 memorized_func = mem(
 	add_str,	# 計算結果をメモ化したい関数
 	"add_str",	# 関数識別用の文字列
-	confirm = False,	# メモ読み込みの確認有無
-	mem_dir = "./"	# メモの置き場所
+	mem_dir = "./",	# メモの置き場所
+	confirm = False	# メモ読み込みの確認有無
 )
 ret_str = memorized_func("Hello", ", World!!\n")
 # 動作確認
